PyChart
=======

Libreria python per generare semplici grafici tramite la libreria Pillow.

Versione 1.0.6

Installazione
-------------

pip install PyChart-busnellistefano -U

Utilizzo
--------

$ python
import pychart

Classi
------

* Mapper

* Graph

* Panel

* Chart
